Module blaxel.core.client.models.jobs_executions
================================================

Classes
-------

`JobsExecutions(failed: blaxel.core.client.types.Unset | int = <blaxel.core.client.types.Unset object>, running: blaxel.core.client.types.Unset | int = <blaxel.core.client.types.Unset object>, success: blaxel.core.client.types.Unset | int = <blaxel.core.client.types.Unset object>, total: blaxel.core.client.types.Unset | int = <blaxel.core.client.types.Unset object>)`
:   Jobs executions
    
    Attributes:
        failed (Union[Unset, int]): Failed executions
        running (Union[Unset, int]): Running executions
        success (Union[Unset, int]): Success executions
        total (Union[Unset, int]): Total executions
    
    Method generated by attrs for class JobsExecutions.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `failed: blaxel.core.client.types.Unset | int`
    :

    `running: blaxel.core.client.types.Unset | int`
    :

    `success: blaxel.core.client.types.Unset | int`
    :

    `total: blaxel.core.client.types.Unset | int`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :